# DATA42

## Library specializing in data cleaning, visualization and prediction. 
## Highly paired with Pandas library. The functions receive as input parameter a dataframe and return it updated.

## Cleaning: Remove characters, filter values, decoding, treatment of outliers and missings, type change and dates formating.
## Visualization: data reports, plots and correlation tests.
## Learning: Balance datasets, best model and params selector and classification metrics.